*Experimental* CKMR tagging likelihood
g3l_tagging_ckmr(
nll_name,
obs_data,
fleets,
parent_stocks,
offspring_stocks,
weight = g3_parameterized(paste0(nll_name, "_weight"),
optimise = FALSE, value = 1),
run_at = g3_action_order$likelihood)An action (i.e. list of formula objects) that will...
For all parent_stocks and offspring_stocks, collect spawing rate into modelhist__spawning and modelhist__spawned, total number of parents and total number of spawned offspring respectively
For all fleets, collect catch data into modelhist__catch
For any observed pairs that year, include the probability of that event happening into nll
Character string, used to define the variable name for obsstock and modelstock.
Data.frame of observed mother-offspring pairs with columns year / parent_age / offspring_age / mo_pairs
A list of g3_stock objects to collect catch data for.
A list of g3_stock objects that are parents in a g3a_spawn action
A list of g3_stock objects that are output_stocks in a g3a_spawn action
Weighting applied to this likelihood component. Default is a g3_param
that defaults to 1, allowing weights to be altered without recompiling.
Integer order that actions will be run within model, see g3_action_order.
Implementation of CKMR based on Bravington, M.V., Skaug, H.J., & Anderson, E.C. (2016). Close-Kin Mark-Recapture. Statistical Science, 31, 259-274.
Only one kinship probability is implemented, mother-offspring with lethal sampling, i.e. (3.2) in the paper. This is then used as a pseudo-likelihood as per (4.1).
The obs_data data.frame provides observed pairs. Unlike other likelihood mehthods, it has a fixed structure:
Year of observation for the data point.
Age of the parent in an observed parent-offspring pair.
Age of the offspring in an observed parent-offspring pair.
Number of pairs observed with these ages.
Bravington, M.V., Skaug, H.J., & Anderson, E.C. (2016). Close-Kin Mark-Recapture. Statistical Science, 31, 259-274.
g3_stock